Trait Recording
pub trait Recording {
// Provided methods
fn start(&mut self) { ... }
fn stop(&mut self) { ... }
}Expand description
Marks the timed region of a single benchmark iteration.
Provided Methods
fn start(&mut self)
fn start(&mut self)
Start the timed region, just before the benchmarked code runs.
fn stop(&mut self)
fn stop(&mut self)
Stop the timed region, just after the benchmarked code runs.